#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <string>
#ifdef HAVE_GL_GL_H
#  include <GL/gl.h>
#elif HAVE_OPENGL_GL_H
#  include <OpenGL/gl.h>
#endif
#ifdef HAVE_GL_GLU_H
#  include <GL/glu.h>
#elif HAVE_OPENGL_GLU_H
#  include <OpenGL/glu.h>
#endif
#include "height_quantity.hh"

using std::string;

HeightQuantity::HeightQuantity(const string &name,
			       GLdouble offset, GLdouble scale,
			       GLfloat red, GLfloat green, GLfloat blue):
  offset(offset), scale(scale), red(red), green(green), blue(blue), name(name),
  frame_number(-1){
  GLenum glerror;
  this->display_list = glGenLists(1);
  if((glerror = glGetError()) != GL_NO_ERROR) throw gluErrorString(glerror);
}

HeightQuantity::~HeightQuantity(void){
  if(glIsList(this->display_list) == GL_TRUE)
    glDeleteLists(this->display_list, 1);
}

void HeightQuantity::draw(int frame){
  if(!this->dynamic) frame = 0;
  if(this->frame_number != frame) this->compile(frame);
  this->frame_number = frame;
  glPushMatrix();
  glScalef(1, 1, this->scale);
  glTranslatef(0, 0, this->offset);
  glColor3f(this->red, this->green, this->blue);
  glCallList(this->display_list);
  glPopMatrix();
}

const string &HeightQuantity::get_name(void){
  return this->name;
}

void HeightQuantity::set_dynamic(bool dynamic){
  this->dynamic = dynamic;
}

void HeightQuantity::compile(int frame){
  
}
